@@ -6,9 +6,7 @@
 
 #include "application.h"
 
-#include "actionsmodel.h"
 #include "audiosettings.h"
-#include "customcommandsmodel.h"
 #include "generalsettings.h"
 #include "global.h"
 #include "haruna-version.h"
@@ -16,18 +14,13 @@
 #include "mousesettings.h"
 #include "mpvitem.h"
 #include "mpvpreview.h"
+#include "mpvproperties.h"
 #include "playbacksettings.h"
-#include "playlistitem.h"
-#include "playlistmodel.h"
 #include "playlistsettings.h"
-#include "recentfilesmodel.h"
-#include "subtitlesfoldersmodel.h"
 #include "subtitlessettings.h"
-#include "tracksmodel.h"
 #include "videosettings.h"
 #include "worker.h"
 
-#include "mpvproperties.h"
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDesktopServices>
@@ -36,7 +29,6 @@
 #include <QFontDatabase>
 #include <QGuiApplication>
 #include <QMimeDatabase>
-#include <QQuickItem>
 #include <QQuickView>
 #include <QStandardPaths>
 #include <QStyle>
@@ -50,7 +42,6 @@
 #include <KFileItem>
 #include <KFileMetaData/Properties>
 #include <KLocalizedString>
-#include <KStartupInfo>
 #include <KWindowConfig>
 #include <KWindowSystem>
 
@@ -65,13 +56,13 @@ Application::Application()
     , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath()))
     , m_schemes(new KColorSchemeManager(this))
     , m_systemDefaultStyle(m_app->style()->objectName())
+    , m_appEventFilter{std::make_unique<ApplicationEventFilter>()}
 {
     // used to hide playlist when mouse leaves the application
     // while moving between monitors while in fullscreen
-    auto *appEventFilter = new ApplicationEventFilter();
-    m_app->installEventFilter(appEventFilter);
-    QObject::connect(appEventFilter, &ApplicationEventFilter::applicationMouseLeave, this, &Application::qmlApplicationMouseLeave);
-    QObject::connect(appEventFilter, &ApplicationEventFilter::applicationMouseEnter, this, &Application::qmlApplicationMouseEnter);
+    m_app->installEventFilter(m_appEventFilter.get());
+    QObject::connect(m_appEventFilter.get(), &ApplicationEventFilter::applicationMouseLeave, this, &Application::qmlApplicationMouseLeave);
+    QObject::connect(m_appEventFilter.get(), &ApplicationEventFilter::applicationMouseEnter, this, &Application::qmlApplicationMouseEnter);
 
     if (GeneralSettings::guiStyle() != QStringLiteral("System")) {
         QApplication::setStyle(GeneralSettings::guiStyle());
@@ -80,13 +71,16 @@ Application::Application()
     setupWorkerThread();
     setupAboutData();
     setupCommandLineParser();
-    registerQmlTypes();
     setupQmlSettingsTypes();
 
     connect(Global::instance(), &Global::error, this, &Application::error);
     connect(this, &Application::saveWindowGeometryAsync, Worker::instance(), &Worker::saveWindowGeometry, Qt::QueuedConnection);
 }
 
+Application::~Application()
+{
+}
+
 void Application::setupWorkerThread()
 {
     auto worker = Worker::instance();
@@ -120,8 +114,8 @@ void Application::setupAboutData()
 
 void Application::setupCommandLineParser()
 {
-    m_parser = new QCommandLineParser();
-    m_aboutData.setupCommandLine(m_parser);
+    m_parser = std::make_unique<QCommandLineParser>();
+    m_aboutData.setupCommandLine(m_parser.get());
     m_parser->addPositionalArgument(QStringLiteral("file"), i18nc("@info:shell", "File to open"));
 
     QCommandLineOption ytdlFormatSelectionOption(QStringList() << QStringLiteral("ytdl-format-selection") << QStringLiteral("ytdlfs"),
@@ -133,41 +127,24 @@ void Application::setupCommandLineParser()
     m_parser->addOption(ytdlFormatSelectionOption);
 
     m_parser->process(*m_app);
-    m_aboutData.processCommandLine(m_parser);
+    m_aboutData.processCommandLine(m_parser.get());
 
     for (auto i = 0; i < m_parser->positionalArguments().size(); ++i) {
         addUrl(i, m_parser->positionalArguments().at(i));
     }
 }
 
-void Application::registerQmlTypes()
-{
-    qmlRegisterType<MpvItem>("org.kde.haruna", 1, 0, "MpvItem");
-    qmlRegisterType<MpvPreview>("org.kde.haruna", 1, 0, "MpvPreview");
-    qRegisterMetaType<PlaylistModel *>();
-    qRegisterMetaType<TracksModel *>();
-    qRegisterMetaType<KFileMetaData::PropertyMultiMap>("KFileMetaData::PropertyMultiMap");
-    // models
-    qmlRegisterType<SubtitlesFoldersModel>("org.kde.haruna.models", 1, 0, "SubtitlesFoldersModel");
-    qmlRegisterType<ActionsModel>("org.kde.haruna.models", 1, 0, "ActionsModel");
-    qmlRegisterType<ProxyActionsModel>("org.kde.haruna.models", 1, 0, "ProxyActionsModel");
-    qmlRegisterType<CustomCommandsModel>("org.kde.haruna.models", 1, 0, "CustomCommandsModel");
-    qmlRegisterType<RecentFilesModel>("org.kde.haruna.models", 1, 0, "RecentFilesModel");
-    qmlRegisterType<PlaylistProxyModel>("org.kde.haruna.models", 1, 0, "PlaylistProxyModel");
-    qmlRegisterType<PlaylistModel>("org.kde.haruna.models", 1, 0, "PlaylistModel");
-}
-
 void Application::setupQmlSettingsTypes()
 {
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "MpvProperties", MpvProperties::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "AudioSettings", AudioSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "GeneralSettings", GeneralSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "InformationSettings", InformationSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "MouseSettings", MouseSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "PlaybackSettings", PlaybackSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "PlaylistSettings", PlaylistSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "SubtitlesSettings", SubtitlesSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "VideoSettings", VideoSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.mpvproperties", 1, 0, "MpvProperties", MpvProperties::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "AudioSettings", AudioSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "GeneralSettings", GeneralSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "InformationSettings", InformationSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "MouseSettings", MouseSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "PlaybackSettings", PlaybackSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "PlaylistSettings", PlaylistSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "SubtitlesSettings", SubtitlesSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "VideoSettings", VideoSettings::self());
 }
 
 void Application::restoreWindowGeometry(QQuickWindow *window) const
@@ -203,30 +180,36 @@ bool Application::pathExists(const QString &path)
 QUrl Application::configFilePath()
 {
     auto file = Global::instance()->appConfigFilePath();
-    return pathToUrl(file);
+    if (pathExists(file)) {
+        return pathToUrl(file);
+    }
+    return QUrl();
 }
 
 QUrl Application::ccConfigFilePath()
 {
-    auto file = Global::instance()->appConfigFilePath(Global::CustomCommands);
-    return pathToUrl(file);
+    auto file = Global::instance()->appConfigFilePath(Global::ConfigFile::CustomCommands);
+    if (pathExists(file)) {
+        return pathToUrl(file);
+    }
+    return QUrl();
 }
 
 QUrl Application::configFolderPath()
 {
     auto folder = Global::instance()->appConfigDirPath();
-    return pathToUrl(folder);
+    if (pathExists(folder)) {
+        return pathToUrl(folder);
+    }
+    return QUrl();
 }
 
 QUrl Application::pathToUrl(const QString &path)
 {
-    QUrl url(path);
+    auto url = QUrl::fromUserInput(path);
     if (!url.isValid()) {
         return QUrl();
     }
-    if (url.scheme().isEmpty()) {
-        url.setScheme(QStringLiteral("file"));
-    }
     return url;
 }
 
@@ -365,7 +348,7 @@ void Application::setQmlEngine(QQmlApplicationEngine *_qmlEngine)
 
 QCommandLineParser *Application::parser() const
 {
-    return m_parser;
+    return m_parser.get();
 }
 
 void Application::activateColorScheme(const QString &name)
@@ -380,8 +363,7 @@ void Application::openDocs(const QString &page)
 
 QStringList Application::getFonts()
 {
-    static QFontDatabase *fontDB = new QFontDatabase();
-    return fontDB->families();
+    return QFontDatabase::families();
 }
 
 int Application::frameworksVersionMinor()
@@ -409,12 +391,7 @@ void Application::raiseWindow()
     // todo: replace deprecated methods
     QWindow *window = qobject_cast<QWindow *>(m_rootObject);
     if (window) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        KStartupInfo::setNewStartupId(window, KStartupInfo::startupId());
-        KWindowSystem::activateWindow(window->winId());
-#else
         KWindowSystem::activateWindow(window);
-#endif
     }
 }
 
