@@ -6,19 +6,12 @@
 
 #include "playlistmodel.h"
 
-#include "application.h"
-#include "generalsettings.h"
-#include "playlistsettings.h"
-#include "worker.h"
-
 #include <KFileItem>
 #include <KFileMetaData/Properties>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 #include <KIO/DeleteOrTrashJob>
-#endif
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/RenameFileDialog>
+#include <kio_version.h>
 
 #include <QClipboard>
 #include <QCollator>
@@ -30,6 +23,11 @@
 #include <QJsonValue>
 #include <QProcess>
 
+#include "application.h"
+#include "generalsettings.h"
+#include "playlistsettings.h"
+#include "worker.h"
+
 PlaylistModel::PlaylistModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -42,7 +40,8 @@ PlaylistModel::PlaylistModel(QObject *parent)
         auto duration = metaData.value(KFileMetaData::Property::Duration).toInt();
         auto title = metaData.value(KFileMetaData::Property::Title).toString();
 
-        m_playlist[i].duration = Application::formatTime(duration);
+        m_playlist[i].formattedDuration = Application::formatTime(duration);
+        m_playlist[i].duration = duration;
         m_playlist[i].mediaTitle = title;
 
         Q_EMIT dataChanged(index(i, 0), index(i, 0));
@@ -51,6 +50,7 @@ PlaylistModel::PlaylistModel(QObject *parent)
 
 int PlaylistModel::rowCount(const QModelIndex &parent) const
 {
+    Q_UNUSED(parent)
     return m_playlist.count();
 }
 
@@ -69,7 +69,7 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
     case PathRole:
         return QVariant(item.url);
     case DurationRole:
-        return QVariant(item.duration);
+        return QVariant(item.formattedDuration);
     case PlayingRole:
         return QVariant(m_playingItem == index.row());
     case FolderPathRole:
@@ -167,9 +167,7 @@ void PlaylistModel::appendItem(const QUrl &url)
     if (itemInfo.exists() && itemInfo.isFile()) {
         item.url = url;
         item.filename = itemInfo.fileName();
-        item.mediaTitle = QString();
         item.folderPath = itemInfo.absolutePath();
-        item.duration = QString();
     } else {
         if (url.scheme().startsWith(QStringLiteral("http"))) {
             item.url = url;
@@ -227,9 +225,7 @@ void PlaylistModel::getSiblingItems(const QUrl &url)
         PlaylistItem item;
         item.url = fileUrl;
         item.filename = fileInfo.fileName();
-        item.mediaTitle = QString();
         item.folderPath = fileInfo.absolutePath();
-        item.duration = QString();
         m_playlist.append(item);
         if (url == fileUrl) {
             setPlayingItem(m_playlist.count() - 1);
@@ -285,16 +281,16 @@ void PlaylistModel::addM3uItems(const QUrl &url)
 void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
 {
     // use youtube-dl to get the required playlist info as json
-    auto ytdlProcess = new QProcess();
+    auto ytdlProcess = std::make_shared<QProcess>();
     auto args = QStringList() << QStringLiteral("-J") << QStringLiteral("--flat-playlist") << url.toString();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
     ytdlProcess->setArguments(args);
     ytdlProcess->start();
 
-    connect(ytdlProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
+    connect(ytdlProcess.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
         QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
         QJsonValue entries = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("entries")];
-        QString playlistTitle = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
+        // QString playlistTitle = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
         if (entries.toArray().isEmpty()) {
             return;
         }
@@ -310,8 +306,8 @@ void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
             item.url = QUrl::fromUserInput(url);
             item.filename = !title.isEmpty() ? title : url;
             item.mediaTitle = !title.isEmpty() ? title : url;
-            item.folderPath = QString();
-            item.duration = Application::formatTime(duration);
+            item.formattedDuration = Application::formatTime(duration);
+            item.duration = duration;
 
             beginInsertRows(QModelIndex(), m_playlist.count(), m_playlist.count());
             m_playlist.append(item);
@@ -332,22 +328,23 @@ void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
 
 void PlaylistModel::getHttpItemInfo(const QUrl &url, int row)
 {
-    auto ytdlProcess = new QProcess();
+    auto ytdlProcess = std::make_shared<QProcess>();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
     ytdlProcess->setArguments(QStringList() << QStringLiteral("-j") << url.toString());
     ytdlProcess->start();
 
-    connect(ytdlProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
+    connect(ytdlProcess.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
         QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
         QString title = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
-        int duration = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("duration")].toInt();
+        auto duration = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("duration")].toDouble();
         if (title.isEmpty()) {
             // todo: log if can't get title
             return;
         }
         m_playlist[row].mediaTitle = title;
         m_playlist[row].filename = title;
-        m_playlist[row].duration = Application::formatTime(duration);
+        m_playlist[row].formattedDuration = Application::formatTime(duration);
+        m_playlist[row].duration = duration;
 
         Q_EMIT dataChanged(index(row, 0), index(row, 0));
     });
@@ -365,14 +362,15 @@ bool PlaylistModel::isVideoOrAudioMimeType(const QString &mimeType)
 
 void PlaylistModel::setPlayingItem(int i)
 {
-    if (i == -1) {
+    if (i < -1 || i >= m_playlist.size()) {
         return;
     }
 
-    int previousItem = m_playingItem;
+    int previousItem{m_playingItem};
     m_playingItem = i;
     Q_EMIT dataChanged(index(previousItem, 0), index(previousItem, 0));
     Q_EMIT dataChanged(index(i, 0), index(i, 0));
+
     Q_EMIT playingItemChanged();
 
     GeneralSettings::setLastPlayedFile(m_playlist[i].url.toString());
@@ -467,11 +465,7 @@ void PlaylistProxyModel::saveM3uFile(const QString &path)
 void PlaylistProxyModel::highlightInFileManager(int row)
 {
     QString path = data(index(row, 0), PlaylistModel::PathRole).toString();
-    QUrl url(path);
-    if (url.scheme().isEmpty()) {
-        url.setScheme(QStringLiteral("file"));
-    }
-    KIO::highlightInFileManager({url});
+    KIO::highlightInFileManager({QUrl::fromUserInput(path)});
 }
 
 void PlaylistProxyModel::removeItem(int row)
@@ -509,7 +503,6 @@ void PlaylistProxyModel::renameFile(int row)
 
 void PlaylistProxyModel::trashFile(int row)
 {
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     QList<QUrl> urls;
     QString path = data(index(row, 0), PlaylistModel::PathRole).toString();
     QUrl url(path);
@@ -529,7 +522,6 @@ void PlaylistProxyModel::trashFile(int row)
             endRemoveRows();
         }
     });
-#endif
 }
 
 void PlaylistProxyModel::copyFileName(int row)
