@@ -10,18 +10,22 @@
 #include <QAbstractListModel>
 #include <QSortFilterProxyModel>
 #include <QUrl>
+#include <QtQml/qqmlregistration.h>
 
 struct PlaylistItem {
     QUrl url;
     QString filename;
     QString mediaTitle;
     QString folderPath;
-    QString duration;
+    QString formattedDuration;
+    double duration{0.0};
 };
 
 class PlaylistProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(PlaylistProxyModel)
+
 public:
     explicit PlaylistProxyModel(QObject *parent = nullptr);
 
@@ -51,6 +55,8 @@ public:
 class PlaylistModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(PlaylistModel)
+
 public:
     explicit PlaylistModel(QObject *parent = nullptr);
     friend class PlaylistProxyModel;
@@ -65,6 +71,7 @@ public:
         PlayingRole,
         IsLocalRole,
     };
+    Q_ENUM(Roles)
 
     enum Behaviour {
         Append,
